==> decoupled_toolbox-1.0.1-rc1.tar.gz: decoupled_toolbox/src/Plugin/Field/FieldFormatter/DecoupledFormatterInterface.php <==
<?php

namespace Drupal\decoupled_toolbox\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\decoupled_toolbox\FieldValueAndOptions;

/**
 * Decoupled formatter interface.
 */
interface DecoupledFormatterInterface {

  /**
   * Gets the cache tags of the rendered field.
   *
   * This should return cache tags especially on entity reference fields.
   *
   * @return array
   *   The cache tags.
   *
   * @throws \Drupal\decoupled_toolbox\Exception\FieldNotYetProcessedException
   */
  public function getProcessedFieldCacheTags(): array;

  /**
   * Builds decoupled output for a field.
   *
   * Call $this->validateSettingsOnRender() before processing the values to
   * validate the formatter settings.
   *
   * The processed field cache tags may be set from this function.
   *
   * @param \Drupal\Core\Field\FieldItemListInterface $items
   *   The field values to be rendered.
   * @param string $langCode
   *   The language that should be used to render the field.
   *
   * @return \Drupal\decoupled_toolbox\FieldValueAndOptions
   *   An array structured as the following:
   *   - array values: array of the values ready for decoupled output.
   *   - array tags: array of cache tags which were retrieved from the items.
   *
   * @throws \Drupal\decoupled_toolbox\Exception\InvalidContentException
   *   Error when processing a field value.
   * @throws \Drupal\decoupled_toolbox\Exception\InvalidFormatterSettingsException
   *   Wrong settings on the formatter.
   * @throws \Drupal\decoupled_toolbox\Exception\UnexpectedFormatterException
   *   The formatter is not compatible with the field.
   */
  public function viewElementsForDecoupled(FieldItemListInterface $items, $langCode): FieldValueAndOptions;

  /**
   * Return the structure of output formatter.
   *
   * @return mixed
   *   Usually can be an keyed array or direct value (integer, string...).
   */
  public static function getOutputDefinitions();

}

==> decoupled_toolbox-1.5.1-rc10.tar.gz: decoupled_toolbox/src/Plugin/Field/FieldFormatter/DecoupledFormatterInterface.php <==
<?php

namespace Drupal\decoupled_toolbox\Plugin\Field\FieldFormatter;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\decoupled_toolbox\FieldValueAndOptions;

/**
 * Decoupled formatter interface.
 */
interface DecoupledFormatterInterface {

  /**
   * Gets the cache tags of the rendered field.
   *
   * This should return cache tags especially on entity reference fields.
   *
   * @return array
   *   The cache tags.
   *
   * @throws \Drupal\decoupled_toolbox\Exception\FieldNotYetProcessedException
   */
  public function getProcessedFieldCacheTags(): array;

  /**
   * Builds decoupled output for a field.
   *
   * Call $this->validateSettingsOnRender() before processing the values to
   * validate the formatter settings.
   *
   * The processed field cache tags may be set from this function.
   *
   * @param \Drupal\Core\Field\FieldItemListInterface $items
   *   The field values to be rendered.
   * @param string $langCode
   *   The language that should be used to render the field.
   *
   * @return \Drupal\decoupled_toolbox\FieldValueAndOptions
   *   An array structured as the following:
   *   - array values: array of the values ready for decoupled output.
   *   - array tags: array of cache tags which were retrieved from the items.
   *
   * @throws \Drupal\decoupled_toolbox\Exception\InvalidContentException
   *   Error when processing a field value.
   * @throws \Drupal\decoupled_toolbox\Exception\InvalidFormatterSettingsException
   *   Wrong settings on the formatter.
   * @throws \Drupal\decoupled_toolbox\Exception\UnexpectedFormatterException
   *   The formatter is not compatible with the field.
   */
  public function viewElementsForDecoupled(FieldItemListInterface $items, $langCode): FieldValueAndOptions;

  /**
   * Return the structure of output formatter.
   *
   * @return array|string
   *   Usually a keyed array or direct value (integer, string...).
   */
  public static function getOutputDefinitions();

}
